RankBasedMetricResults
======================

.. currentmodule:: pykeen.evaluation

.. autoclass:: RankBasedMetricResults
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~RankBasedMetricResults.from_dict
      ~RankBasedMetricResults.from_json
      ~RankBasedMetricResults.get_metric
      ~RankBasedMetricResults.schema
      ~RankBasedMetricResults.to_df
      ~RankBasedMetricResults.to_dict
      ~RankBasedMetricResults.to_flat_dict
      ~RankBasedMetricResults.to_json

   .. rubric:: Methods Documentation

   .. automethod:: from_dict
   .. automethod:: from_json
   .. automethod:: get_metric
   .. automethod:: schema
   .. automethod:: to_df
   .. automethod:: to_dict
   .. automethod:: to_flat_dict
   .. automethod:: to_json
